@@ -298,7 +298,8 @@ class Step(object):
             def elsewhere(step):
                 # actual step behavior, maybe.
 
-        This will raise error (thus halting execution of the step) if a subordinate step fails.
+        This will raise the error of the first failing step (thus halting 
+        execution of the step) if a subordinate step fails.
 
         """
         lines = string.split('\n')
@@ -312,7 +313,7 @@ class Step(object):
         else:
             self.passed = False
             self.failed = True
-            assert not steps_failed, "Subordinate steps failed for this step."
+            assert not steps_failed, steps_failed[0].why.exception
 
     def run(self, ignore_case):
         """Runs a step, trying to resolve it on available step
@@ -602,6 +603,8 @@ class Scenario(object):
     @classmethod
     def from_string(new_scenario, string, with_file=None, original_string=None, language=None):
         """ Creates a new scenario from string"""
+        # ignoring comments
+        string = "\n".join(strings.get_stripped_lines(string, ignore_lines_starting_with='#'))
 
         if not language:
             language = Language()
@@ -700,11 +703,11 @@ class Feature(object):
     @classmethod
     def from_string(new_feature, string, with_file=None, language=None):
         """Creates a new feature from string"""
-        lines = strings.get_stripped_lines(string)
+        lines = strings.get_stripped_lines(string, ignore_lines_starting_with='#')
         if not language:
             language = Language()
 
-        found = len(re.findall(r'%s:[ ]*\w+' % language.feature, string))
+        found = len(re.findall(r'%s:[ ]*\w+' % language.feature, "\n".join(lines)))
 
         if found > 1:
             raise LettuceSyntaxError(
